==> haskell-ghc-mod-5.5.0.0-17-armv7h.pkg.tar.xz: usr/share/haskell/haskell-ghc-mod/register.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: ghc-mod
version: 5.5.0.0
id: ghc-mod-5.5.0.0-685cdf7f391844595dff1ad727107d28
key: ghcmo_7GkrusqGYS2EHqjDGzH0lV
license: AGPL-3
maintainer: Daniel Gröber <dxld@darkboxed.org>
homepage: http://www.mew.org/~kazu/proj/ghc-mod/
synopsis: Happy Haskell Programming
description:
    ghc-mod is a backend program to enrich Haskell programming in editors. It
    strives to offer most of the features one has come to expect from modern IDEs
    in any editor.
    ghc-mod provides a library for other haskell programs to use as well as a
    standalone program for easy editor integration. All of the fundamental
    functionality of the frontend program can be accessed through the library
    however many implementation details are hidden and if you want to
    significantly extend ghc-mod you should submit these changes upstream instead
    of implementing them on top of the library.
    For more information, please see its home page.
category: GHC, Development
author: Kazu Yamamoto <kazu@iij.ad.jp>,
        Daniel Gröber <dxld@darkboxed.org>,
        Alejandro Serrano <trupill@gmail.com>,
        Nikolay Yakimov <root@livid.pp.ru>
exposed: True
exposed-modules:
    Language.Haskell.GhcMod Language.Haskell.GhcMod.Internal
    Language.Haskell.GhcMod.Boot Language.Haskell.GhcMod.Browse
    Language.Haskell.GhcMod.CabalHelper Language.Haskell.GhcMod.Caching
    Language.Haskell.GhcMod.Caching.Types
    Language.Haskell.GhcMod.CaseSplit Language.Haskell.GhcMod.Check
    Language.Haskell.GhcMod.Convert Language.Haskell.GhcMod.Cradle
    Language.Haskell.GhcMod.CustomPackageDb
    Language.Haskell.GhcMod.Debug Language.Haskell.GhcMod.DebugLogger
    Language.Haskell.GhcMod.Doc Language.Haskell.GhcMod.DynFlags
    Language.Haskell.GhcMod.Error Language.Haskell.GhcMod.FileMapping
    Language.Haskell.GhcMod.FillSig Language.Haskell.GhcMod.Find
    Language.Haskell.GhcMod.Flag Language.Haskell.GhcMod.Gap
    Language.Haskell.GhcMod.GhcPkg
    Language.Haskell.GhcMod.HomeModuleGraph
    Language.Haskell.GhcMod.Info Language.Haskell.GhcMod.Lang
    Language.Haskell.GhcMod.Lint Language.Haskell.GhcMod.LightGhc
    Language.Haskell.GhcMod.Logger Language.Haskell.GhcMod.Logging
    Language.Haskell.GhcMod.Modules Language.Haskell.GhcMod.Monad
    Language.Haskell.GhcMod.Monad.Env Language.Haskell.GhcMod.Monad.Log
    Language.Haskell.GhcMod.Monad.Newtypes
    Language.Haskell.GhcMod.Monad.Orphans
    Language.Haskell.GhcMod.Monad.Out
    Language.Haskell.GhcMod.Monad.State
    Language.Haskell.GhcMod.Monad.Types Language.Haskell.GhcMod.Output
    Language.Haskell.GhcMod.PathsAndFiles
    Language.Haskell.GhcMod.PkgDoc Language.Haskell.GhcMod.Pretty
    Language.Haskell.GhcMod.Read Language.Haskell.GhcMod.SrcUtils
    Language.Haskell.GhcMod.Stack Language.Haskell.GhcMod.Target
    Language.Haskell.GhcMod.Test Language.Haskell.GhcMod.Types
    Language.Haskell.GhcMod.Utils Language.Haskell.GhcMod.World
hidden-modules: Paths_ghc_mod Utils Data.Binary.Generic
                System.Directory.ModTime
trusted: False
import-dirs: /usr/lib/ghc-7.10.3/site-local/ghc-mod-5.5.0.0
library-dirs: /usr/lib/ghc-7.10.3/site-local/ghc-mod-5.5.0.0
data-dir: /usr/share/ghc-mod
hs-libraries: HSghc-mod-5.5.0.0-7GkrusqGYS2EHqjDGzH0lV
depends:
    base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
    binary-0.7.5.0-29f7044fa0b12dc5c2dcec897db5c464
    bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
    cabal-helper-0.6.3.1-512cee1d780890ae55b68b9cff633e01
    containers-0.5.6.2-169e53288f333dd2f0207994fd53822f
    deepseq-1.4.1.1-3975618f889b45239daa47b7443eaeee
    directory-1.2.2.0-17b2023f9d7e8036d19e6b52b4f75c98
    djinn-ghc-0.0.2.3-577e03de8f4226a7d09d3ffa14d2e949
    extra-1.4.3-ab419342055a04bda9f8a7a264d348c1
    fclabels-2.0.3-cd90e167314c59156e7d15f06cdc4648
    filepath-1.4.0.0-73e0bec80594160bf6dd6cb25217c6bf
    ghc-7.10.3-523035ba1e58dc12893f7ef41f66b61d
    ghc-paths-0.1.0.9-e2ef6e39c0da729a67d19f4c6af9f657
    ghc-syb-utils-0.2.3-e762c220d86bac9001fe97a4dd0b5d58
    haskell-src-exts-1.17.1-22ac2cdd01c70a173d0a3e75bc933334
    hlint-1.9.32-90db989eb30a130842bd3014d63efdf6
    monad-control-1.0.0.5-237b0aabd7893e5e3f4b9224e05c849c
    monad-journal-0.7.1-9e11141a847c41c0ccebac743a25d261
    mtl-2.2.1-c516313407bc17046965067cb7cbb6a0
    old-time-1.1.0.3-91625432bd7c61d043f9b743fb82dcf7
    pipes-4.1.8-48aeb04c3fec70e47e537a12d228def1
    pretty-1.1.2.0-b06321e1e395640194b358a5374c465f
    process-1.2.3.0-21d25f1d78aeea6e68f1c768841f9794
    safe-0.3.9-b613242f536083d5bb04920ede356aea
    split-0.2.3-1755fd7a4bff52537a62f0056f73dfbc
    syb-0.6-56a5944f55f7a9d47e7b770375c0e1ae
    temporary-1.2.0.4-82bc44ff7d47fd2873d477b044a2a6ac
    text-1.2.2.1-18afbfeccf88d72c4b6e468c86d2b77d
    time-1.5.0.1-cf94b0d806e26f6c4e356671290061b2
    transformers-0.4.2.0-252429dba576bc247c1932da496e0a3f
    transformers-base-0.4.4-b65bc998c24abf50fea29d4891da9e32
haddock-interfaces: /usr/share/doc/ghc-mod/html/ghc-mod.haddock
haddock-html: /usr/share/doc/ghc-mod/html
' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"

==> haskell-ghc-mod-5.5.0.0-19-armv7h.pkg.tar.xz: usr/share/haskell/haskell-ghc-mod/register.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: ghc-mod
version: 5.5.0.0
id: ghc-mod-5.5.0.0-8bc05606cb1fe18039c749e00ba585ac
key: ghcmo_JsGifHx9AZ59Zk7WQAchaU
license: AGPL-3
maintainer: Daniel Gröber <dxld@darkboxed.org>
homepage: http://www.mew.org/~kazu/proj/ghc-mod/
synopsis: Happy Haskell Programming
description:
    ghc-mod is a backend program to enrich Haskell programming in editors. It
    strives to offer most of the features one has come to expect from modern IDEs
    in any editor.
    ghc-mod provides a library for other haskell programs to use as well as a
    standalone program for easy editor integration. All of the fundamental
    functionality of the frontend program can be accessed through the library
    however many implementation details are hidden and if you want to
    significantly extend ghc-mod you should submit these changes upstream instead
    of implementing them on top of the library.
    For more information, please see its home page.
category: GHC, Development
author: Kazu Yamamoto <kazu@iij.ad.jp>,
        Daniel Gröber <dxld@darkboxed.org>,
        Alejandro Serrano <trupill@gmail.com>,
        Nikolay Yakimov <root@livid.pp.ru>
exposed: True
exposed-modules:
    Language.Haskell.GhcMod Language.Haskell.GhcMod.Internal
    Language.Haskell.GhcMod.Boot Language.Haskell.GhcMod.Browse
    Language.Haskell.GhcMod.CabalHelper Language.Haskell.GhcMod.Caching
    Language.Haskell.GhcMod.Caching.Types
    Language.Haskell.GhcMod.CaseSplit Language.Haskell.GhcMod.Check
    Language.Haskell.GhcMod.Convert Language.Haskell.GhcMod.Cradle
    Language.Haskell.GhcMod.CustomPackageDb
    Language.Haskell.GhcMod.Debug Language.Haskell.GhcMod.DebugLogger
    Language.Haskell.GhcMod.Doc Language.Haskell.GhcMod.DynFlags
    Language.Haskell.GhcMod.Error Language.Haskell.GhcMod.FileMapping
    Language.Haskell.GhcMod.FillSig Language.Haskell.GhcMod.Find
    Language.Haskell.GhcMod.Flag Language.Haskell.GhcMod.Gap
    Language.Haskell.GhcMod.GhcPkg
    Language.Haskell.GhcMod.HomeModuleGraph
    Language.Haskell.GhcMod.Info Language.Haskell.GhcMod.Lang
    Language.Haskell.GhcMod.Lint Language.Haskell.GhcMod.LightGhc
    Language.Haskell.GhcMod.Logger Language.Haskell.GhcMod.Logging
    Language.Haskell.GhcMod.Modules Language.Haskell.GhcMod.Monad
    Language.Haskell.GhcMod.Monad.Env Language.Haskell.GhcMod.Monad.Log
    Language.Haskell.GhcMod.Monad.Newtypes
    Language.Haskell.GhcMod.Monad.Orphans
    Language.Haskell.GhcMod.Monad.Out
    Language.Haskell.GhcMod.Monad.State
    Language.Haskell.GhcMod.Monad.Types Language.Haskell.GhcMod.Output
    Language.Haskell.GhcMod.PathsAndFiles
    Language.Haskell.GhcMod.PkgDoc Language.Haskell.GhcMod.Pretty
    Language.Haskell.GhcMod.Read Language.Haskell.GhcMod.SrcUtils
    Language.Haskell.GhcMod.Stack Language.Haskell.GhcMod.Target
    Language.Haskell.GhcMod.Test Language.Haskell.GhcMod.Types
    Language.Haskell.GhcMod.Utils Language.Haskell.GhcMod.World
hidden-modules: Paths_ghc_mod Utils Data.Binary.Generic
                System.Directory.ModTime
trusted: False
import-dirs: /usr/lib/ghc-7.10.3/site-local/ghc-mod-5.5.0.0
library-dirs: /usr/lib/ghc-7.10.3/site-local/ghc-mod-5.5.0.0
data-dir: /usr/share/ghc-mod
hs-libraries: HSghc-mod-5.5.0.0-JsGifHx9AZ59Zk7WQAchaU
depends:
    base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
    binary-0.7.5.0-29f7044fa0b12dc5c2dcec897db5c464
    bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
    cabal-helper-0.6.3.1-512cee1d780890ae55b68b9cff633e01
    containers-0.5.6.2-169e53288f333dd2f0207994fd53822f
    deepseq-1.4.1.1-3975618f889b45239daa47b7443eaeee
    directory-1.2.2.0-17b2023f9d7e8036d19e6b52b4f75c98
    djinn-ghc-0.0.2.3-577e03de8f4226a7d09d3ffa14d2e949
    extra-1.4.3-ab419342055a04bda9f8a7a264d348c1
    fclabels-2.0.3-cd90e167314c59156e7d15f06cdc4648
    filepath-1.4.0.0-73e0bec80594160bf6dd6cb25217c6bf
    ghc-7.10.3-523035ba1e58dc12893f7ef41f66b61d
    ghc-paths-0.1.0.9-e2ef6e39c0da729a67d19f4c6af9f657
    ghc-syb-utils-0.2.3-e762c220d86bac9001fe97a4dd0b5d58
    haskell-src-exts-1.17.1-22ac2cdd01c70a173d0a3e75bc933334
    hlint-1.9.32-90db989eb30a130842bd3014d63efdf6
    monad-control-1.0.1.0-0cce93e14e6c79e66d2dc881e1ab9f6e
    monad-journal-0.7.1-868f6722086675c90bd35d95b6eee1b6
    mtl-2.2.1-c516313407bc17046965067cb7cbb6a0
    old-time-1.1.0.3-91625432bd7c61d043f9b743fb82dcf7
    pipes-4.1.8-48aeb04c3fec70e47e537a12d228def1
    pretty-1.1.2.0-b06321e1e395640194b358a5374c465f
    process-1.2.3.0-21d25f1d78aeea6e68f1c768841f9794
    safe-0.3.9-b613242f536083d5bb04920ede356aea
    split-0.2.3-1755fd7a4bff52537a62f0056f73dfbc
    syb-0.6-56a5944f55f7a9d47e7b770375c0e1ae
    temporary-1.2.0.4-82bc44ff7d47fd2873d477b044a2a6ac
    text-1.2.2.1-18afbfeccf88d72c4b6e468c86d2b77d
    time-1.5.0.1-cf94b0d806e26f6c4e356671290061b2
    transformers-0.4.2.0-252429dba576bc247c1932da496e0a3f
    transformers-base-0.4.4-b65bc998c24abf50fea29d4891da9e32
haddock-interfaces: /usr/share/doc/ghc-mod/html/ghc-mod.haddock
haddock-html: /usr/share/doc/ghc-mod/html
' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
